@@ -1,6 +1,29 @@
-(* $Id: charmap.ml,v 1.10 2003/07/31 12:20:58 yori Exp $ *)
+(* $Id: charmap.ml,v 1.11 2006/08/13 17:09:17 yori Exp $ *)
 (* Copyright 2002 Yamagata Yoriyuki *)
 
+module type Interface = sig
+type enc_to_ucs
+
+val make_enc_to_ucs : int -> (string * int) list -> enc_to_ucs
+val no_char_of : enc_to_ucs -> int
+
+type probe_state
+val start_probe : enc_to_ucs -> probe_state
+val look_probe : probe_state -> int -> int
+val next_probe : probe_state -> int -> probe_state option
+
+type t = {
+  name : string;
+  ucs_to_enc : string Tbl31.t;
+  enc_to_ucs : enc_to_ucs;
+} 
+
+type data = Alias of string | CMap of t
+
+val of_name : string -> t
+end
+
+module Configure (Config : ConfigInt.Type) = struct
 type enc_to_ucs = 
     {enc_to_ucs_no_char : int;
      enc_to_ucs_tbl : Byte_labeled_dag.bytes}
@@ -38,10 +61,7 @@ let of_name name =
     | Some x -> x
   with Not_found ->
     let rec look count name = 
-      let filename = 
-	Filename.concat 
-	  Camomileconfig.charmapdir 
-	  (name ^ ".mar") in
+      let filename = Filename.concat Config.charmapdir (name ^ ".mar") in
       let c = try open_in_bin filename with Sys_error _ -> raise Not_found in
       let data : data = input_value c in
       match data with
@@ -54,3 +74,4 @@ let of_name name =
   Weak.set b 0 (Some t);
   Hashtbl.add loaded name b;
   t
+end
