@@ -1,17 +1,62 @@
-(* $Id: uCol.ml,v 1.25 2004/04/06 22:12:48 yori Exp $ *)
+(* $Id: uCol.ml,v 1.27 2006/08/13 17:18:12 yori Exp $ *)
 (* Copyright 2002 Yamagata Yoriyuki *)
 
-open Unidata
-open UCharInfo
 
 type variable_option = 
-  [ `Blanked 
+    [ `Blanked 
   | `Non_ignorable 
   | `Shifted
   | `Shift_Trimmed ]
 
 type precision = [ `Primary | `Secondary | `Tertiary | `Quaternary ]
 
+module type Type =
+sig
+  type text
+  type index
+
+	(** For locale, see {!Locale}.
+	    If [locale] is omitted, the standard UCA order is used.
+	    If [prec] is omitted, the maximum possible strength is used.
+	    If [variable] is omitted, the default of the locale 
+	    (usually [`Shifted]) is used.
+	    The meaning of the returned value is similar to Pervasives.compare *)
+  val compare : 
+      ?locale:string -> ?prec:precision -> ?variable:variable_option -> 
+	text -> text -> int
+
+	    (** Binary comparison of sort_key gives the same result as [compare]. 
+		i.e.
+		[compare t1 t2 = Pervasives.compare (sort_key t1) (sort_key t2)]
+		If the same texts are repeatedly compared, 
+		pre-computation of sort_key gives better performance. *)
+  val sort_key : 
+      ?locale:string -> ?prec:precision -> ?variable:variable_option ->
+	text -> string
+
+(** Comparison with the sort key. *)
+  val compare_with_key :
+      ?locale: string -> ?prec:precision -> ?variable:variable_option ->
+	string -> text -> int
+
+  val search_with_key :
+      ?locale: string -> ?prec:precision -> ?variable:variable_option ->
+	string -> text -> index -> (index * index)
+
+  val search :
+      ?locale: string -> ?prec:precision -> ?variable:variable_option ->
+	text -> text -> index -> (index * index)
+
+end
+
+module Make (Config : ConfigInt.Type) (Text : UnicodeString.Type) = struct
+
+module Unidata = Unidata.Make(Config)
+module UCharInfo = UCharInfo.Make(Config)
+
+open Unidata
+open UCharInfo
+
 let logical_order_exception_tbl = 
   UCharInfo.load_property_tbl `Logical_Order_Exception
 
@@ -441,40 +486,10 @@ let getkey keybuf =
 	Buffer.add_buffer buf1 (quaternary_of_keybuf keybuf));
   Buffer.contents buf1
 
-module type Type =
-sig
-  type text
-  type index
-
-  val compare : 
-      ?locale:string -> ?prec:precision -> ?variable:variable_option -> 
-	text -> text -> int
-
-  val sort_key : 
-      ?locale:string -> ?prec:precision -> ?variable:variable_option ->
-	text -> string
-
-  val compare_with_key :
-      ?locale: string -> ?prec:precision -> ?variable:variable_option ->
-	string -> text -> int
-
-  val search_with_key :
-      ?locale: string -> ?prec:precision -> ?variable:variable_option ->
-	string -> text -> index -> index * index
-
-  val search :
-      ?locale: string -> ?prec:precision -> ?variable:variable_option ->
-	text -> text -> index -> index * index
-
-end
-
-module Make (Text : UnicodeString.Type) =
-  struct
-
     type text = Text.t
     type index = Text.index
 
-    module NF = UNF.Make (Text)
+    module NF = UNF.Make(Config)(Text)
 
     let sort_key_aux col_info prec t =
       let x = XString.make 0 (UChar.chr_of_uint 0) in
@@ -817,5 +832,4 @@ module Make (Text : UnicodeString.Type) =
     let search ?locale ?prec ?variable t0 t loc =
       let k = sort_key ?locale ?prec ?variable t0 in
       search_with_key ?locale ?prec ?variable k t loc
-
-  end
+end
